### Print all runs and objects in a copick project

```python
--8<-- "root_list_objects_runs.py"
```

### Read an object's density map into a numpy array

```python
--8<-- "object_read_map.py"
```


### Print all tomograms in a copick voxel spacing

```python
--8<-- "voxel_spacing_list_tomograms.py"
```


### Read a tomogram into a numpy array

```python
--8<-- "tomogram_read_image.py"
```

### Read a feature array into a numpy array

```python
--8<-- "features_read_image.py"
```

### Read copick picks into a numpy array

```python
--8<-- "point_read.py"
```

### Print all segmentations in a copick run

```python
--8<-- "run_list_segmentations.py"
```

### Read a segmentation into a numpy array

```python
--8<-- "segmentation_read_image.py"
```

### Read a mesh from a copick run

```python
--8<-- "mesh_read.py"
```
